import m from 'mithril';
import './progress.style.css';
export type ProgressAttrs = {
    active?: boolean;
};
export declare class Progress {
    private readonly _runnedIds;
    private id;
    /**
     * Gets information, that progress is active now or not
     * @returns
     */
    isActive(): boolean;
    /**
     * Turn progress on. It adds next request to run progress, and returns function to stop exactly that single request.
     *
     * @example
     * ```javascript
     * // run progress and get callback to turn off that single request of progress
     * const off = progress.on();
     *
     * // make another request for progress
     * const anotherOff = progress.on();
     *
     * // now to turn whole progress off, invoke progress.off() method
     *
     * // below code turns off only single request of progress, but second one is still active, so whole progress is active also:
     * off();
     *
     * // now there is one active request for progress, and still we can make progress off by progress.off function
     * // but invoking callback of second progress request will make, then any requests are present, so whole progress is off also
     * anotherOff();
     * ```
     * @returns callback to stop progress
     */
    on(): () => void;
    /**
     * Stops all running progress requests
     */
    off(): void;
    /**
     * @hidden
     */
    view(): m.Vnode<unknown, unknown>;
    private _offSingle;
}
//# sourceMappingURL=Progress.d.ts.map