import m from 'mithril';
import { Progress } from '../box/Progress';
import { ValidEventTypes } from '../event-emitter/EventEmitter';
import { Component, ComponentAttributes } from './Component';
import { FlexAlignment, FlexJustification } from './Types';
import { Toast } from '../messages/Toast';
import { Message, MessageAttributes } from '../messages/Message';
import { Window, WindowAttributes } from '../window/Window';
import { Popup, PopupAttrs } from '../popup/Popup';
export type ContainerAttributes = ComponentAttributes & {
    content?: string;
    justify?: FlexJustification;
    align?: FlexAlignment;
};
declare type ContentType = string | Component<ComponentAttributes, ValidEventTypes>;
export declare abstract class Container<A extends ContainerAttributes, E extends ValidEventTypes> extends Component<A, E> {
    protected content?: ContentType;
    progress: Progress;
    toast: Toast;
    messages: Message[];
    popups: Popup[];
    windows: Window[];
    constructor(attrs?: A);
    /**
     * Replaces current content of the container. It could be text or another component
     * @param content text to display or component to embed
     */
    attach(content: ContentType): void;
    /**
     * Get current content of the container.
     * @returns content of the container currently embeded
     */
    getContent(): ContentType | undefined;
    createPopup(config: PopupAttrs): Popup;
    createMessage(config: MessageAttributes): Message;
    createWindow(config: WindowAttributes): Window;
    protected _getChildren(): m.Children;
    protected _getView({ className, ...attrs }: m.Attributes): m.Vnode<unknown, unknown>;
}
export {};
//# sourceMappingURL=Container.d.ts.map