import m from 'mithril';
import { Editor, EditorAttributes, EditorEventTypes } from '../Editor';
import { Button } from '../..';
export declare type InputNumberAttributes = EditorAttributes<number> & {
    /**
     * Text to place inside editor as pattern that value should be of. Alternatively it could be used as label describes field.
     */
    placeholder?: string;
    /**
     * Number type defines wheather field's value could contain decimal part or it should be integer. That field is used to format displaying value and to prevent input illegal characters into input
     */
    numberType?: 'integer' | 'decimal';
    /**
     * Decides whater show or hide buttons to decrement and increment field's value. Buttons are placed on the right side of the editor and make input narrower.
     */
    showUpDownButtons?: boolean;
    /**
     * Prefix value is placed in the beggining of the value during displaying formatted value; it is when edior is not focused. When control is focused it is editing and prefix is not displaying then.
     */
    prefix?: string;
    /**
     * Suffix value is placed in the end of the value during displaying formatted value; it is when edior is not focused. When control is focused it is editing and suffix is not displaying then.
     */
    suffix?: string;
    /**
     * Minimal value of the field used during validating
     */
    min?: number;
    /**
     * Maximal value of the field used during validating
     */
    max?: number;
    /**
     * Defines wheather it is possible to set value that is out of <min, max> range or prevent it. When strict mode is on and there was "setValue" method called with value out of range, then min or max value is placed instead
     */
    strict?: boolean;
    /**
     * Specifies value to add or minus by increment or decrement methods
     */
    stepSize?: number;
    /**
     * Function takes current value of control and returns representative text to display. When function is defined, then another formatting configuration (like prefix, suffix, etc.) is not applied.
     * @param value current value of control
     * @returns text to display as value
     */
    valueFormatter?: (value?: number) => string;
};
/**
 * Editor input control of number type. User can type there digit values like integers of decimals. Control has abilities to display current value as formatted text with prefix or suffix, with thousand separators and decimal delimitter and number of decimals based on global library configuration.
 */
export declare class InputNumber extends Editor<number, InputNumberAttributes, EditorEventTypes<number>> {
    private _btnMinus;
    private _btnPlus;
    constructor(attrs?: InputNumberAttributes);
    /**
     * Changes current value of the control by plus amount defined in "stepSize" attribute or 1 by default
     */
    increment(): void;
    /**
     * Changes current value of the control by minus amount defined in "stepSize" attribute or 1 by default
     */
    decrement(): void;
    setDisabled(disabled: boolean): boolean;
    setValue(value?: number | undefined, suppressEvents?: boolean): void;
    protected controlView(): m.Children | m.Vnode<unknown, unknown>;
    /**
     * Checks that value of the control is correct or not and changes style of the control depends on the validation result
     * @param value value to validate control by with
     * @returns true if validation is successed or false in case of failure
     */
    validate(value?: number | undefined): boolean;
    /**
     * Get string represents formatted value of the control. It includes prefix, suffix and separators.
     * @returns formatted value of the field
     */
    getFormattedValue(): string;
    protected _getButtons(): Button[];
    protected _getEditorAttrs(attrs: m.Attributes): m.Attributes;
}
//# sourceMappingURL=InputNumber.d.ts.map